import logging

logger = logging.getLogger('jsuite')

def extract_title(etree):
  """ Extracts article title from a JATS XML ElementTree instance"""
  TITLE_XPATH = '/article/front/article-meta/title-group/article-title'
  query_set = etree.xpath(TITLE_XPATH)

  if len(query_set) is 0:
    return None
  elif len(query_set) is 1:
    return query_set[0].text
  else:
    logger.warn('Multiple article-title elements found')


# coding=utf-8
from .context import jsuite, fixture

import unittest

class CountSuite(unittest.TestCase):
  def test_count_figures(self):
    with fixture('count/4-figures') as f:
      doc = jsuite.from_file(f)
      count = jsuite.count.of_type(doc, 'fig')
      assert(count == 4)


import logging

logger = logging.getLogger('jsuite')

def _text_content(node):
  return " ".join([x.strip() for x in node.itertext() if x.strip() is not ""])

def body_text(etree):
  """ Extracts text content from the body element of a JATS XML ElementTree 
  instance"""
  BODY_XPATH = '/article/body'
  query_set = etree.xpath(BODY_XPATH)

  if len(query_set) is 0:
    logger.warn('No body element found in article.')
    return None
  if len(query_set) is 1:
    return _text_content(query_set[0])



from distutils.core import setup

setup(
  name = 'jsuite',
  packages = ['jsuite'], # this must be the same as the name above
  version = '0.3.0',

  scripts=['bin/jsuite'],
  install_requires = [
    'lxml==3.6.4',
    'clint==0.5.1'
  ],

  description = 'Parsing and manipulation tools for JATS XML files.',
  author = 'Dipanjan Mukherjee',
  author_email = 'dipanjan.mu@gmail.com',
  url = 'https://github.com/schatten/jsuite', # use the URL to the github repo
  download_url = 'https://github.com/schatten/jsuite/tarball/0.1', # I'll explain this in a second
  keywords = ['xml', 'parsing', 'JATS', 'tools'], # arbitrary keywords
  classifiers = [],
)


# coding=utf-8
from .context import jsuite, fixture

import unittest

class ExtractSuite(unittest.TestCase):
  def test_article_title(self):
    with fixture('extract/single-title') as f:
      doc = jsuite.from_file(f)
      title = jsuite.extract.extract_title(doc)
      assert(title == 'Sample article title')

  def test_article_title_unicode(self):
    with fixture('extract/title-with-unicodes') as f:
        doc = jsuite.from_file(f)
        title = jsuite.extract.extract_title(doc)
        assert(title == u'Sample article title † ecolé Straßße')


from .context import jsuite, fixture

import unittest

class ContentSuite(unittest.TestCase):
  def test_body_text(self):
    with fixture('content/full-body') as f:
      doc = jsuite.from_file(f)
      content = jsuite.content.body_text(doc)
      control = "word word word Some text here to talk about things. Let's add some citations now. Linguistic aphorism 1 2 2 2 4 4 4 4"
      assert(content == control)